**Project template for both python packages & Read The Docs**

Basic directory structures and template files for building both python pypi\
packages and documentation for RTD (Read The Docs) using the sphinx theme.

RTD documentation is here: https://new-pyproject.readthedocs.io/en/latest/



